% name = feature_name(C);
%
% Return feature name from structure
%   C: structure as follows:
% Biggest discriminative cluster: C.method = 'cluster', C.quantile = number
% Principal component analysis:   C.method = 'pca', C.components = number
% Independent component analysis: C.method = 'ica', C.components = number
% 16mm^3 cubes:                   C.method = 'cubes', C.size = number
% Most discriminative voxels:     C.method = 'discrim', C.voxels = number
% Most active voxels:             C.method = 'active', C.voxels = number
% Searchlight accuracy:           C.method = 'slight', C.voxels = number
% Recursive-feature-elimination:  C.method = 'rfesvm', C.voxels = number,
%                                 C.remove = number
%
% Author: Jean Honorio
% E-mail: jhonorio@csail.mit.edu
function name = feature_name(C);

% Choose method
if strcmp(C.method,'cluster')
    param = C.quantile;
elseif strcmp(C.method,'pca')
    param = C.components;
elseif strcmp(C.method,'ica')
    param = C.components;
elseif strcmp(C.method,'cubes')
    param = C.size;
elseif strcmp(C.method,'discrim')
    param = C.voxels;
elseif strcmp(C.method,'active')
    param = C.voxels;
elseif strcmp(C.method,'slight')
    param = C.voxels;
elseif strcmp(C.method,'rfesvm')
    param = [C.voxels C.remove];
else
    error('Not a valid feature selection method');
end
if ~isempty(param)
    name = [C.method,sprintf('_%g',param)];
else
    name = C.method;
end
