% [test_labels test_values C] = fld(test_data,mu1,S1,mu2,S2);
%
% Run Fisher linear discriminant
% Learns on train set, predicts test set
%   test_data: #instances by #features data matrices
%   mu1,mu2:   #features mean vectors
%   S1,S2:     #features by #features "scatter" matrices
% Note: Make sure S1,S2 are positive definite before calling this, you
%       can add something to the diagonal, e.g. S->S+alpha*I
%
% Author: Jean Honorio
% E-mail: jhonorio@csail.mit.edu
function [test_labels test_values C] = fld(test_data,mu1,S1,mu2,S2);

% Check input
[num_instances num_features] = size(test_data);
if length(mu1) ~= num_features | length(mu2) ~= num_features
    error('Data and mean vector have different number of features');
end
if size(S1,1) ~= num_features | size(S1,2) ~= num_features | ...
   size(S2,1) ~= num_features | size(S2,2) ~= num_features
    error('Data and scatter matrix have different number of features');
end

% Learn on training data
C.weight = (S1 + S2) \ (mu1(:) - mu2(:));
C.weight = [C.weight; -dot(C.weight,mu1(:) + mu2(:))/2];

% Predict on test data
test_values = [test_data, ones(num_instances,1)] * C.weight;
test_labels = 2 - double(test_values > 0);
