clear all
clc

%{
% List of subjects
% It will be replaced for "[subject]" in ff_contrasts variable
subjects = {'Sub001', 'Sub002', 'Sub003', 'Sub004', 'Sub005', 'Sub006', 'Sub007', 'Sub008'};

% Label for each subject, either 1 or 2
labels = [2 2 2 1 2 1 1 1];

% For cross-validation, each subject can have a fold starting from 1, e.g. [1 1 2 2 3 3 4 4]
% If empty then each subject is a fold (leave-one-subject-out)
fold_subject = [];

% Scaling
scaling = 'gmsca100';

% Folder contraining contrast maps
% Variable subjects and contrasts will be replaced for each subject and contrast
ff_contrasts = '/MyFolderWithContrastMaps/[contrast]/con_[subject]_[contrast].img';

% Output folder
root_output = '/MyOutputFolder/';

% Fancy names of each entry in contrasts variable
% It will be used in output folder
tasks = {'A','B','C'};

% It will be replaced for "[contrast]" in ff_contrasts variable
contrasts = {'ExpCondA_Avg','ExpCondB_Avg','ExpCondC_Avg'};
%}

subjects = {'0172', '0179', '0185', '0187', '0201', '0206', '0224', '0237'};
labels = [2 2 2 1 2 1 1 1];
fold_subject = [];
scaling = 'gmsca100';
ff_contrasts = '/Jean-Stuff/MoneyTask/Data-Contrasts/[contrast]/con_[subject]_[contrast].img';
root_output = '/Users/spongebob/Desktop/tmp2/';
tasks = {'45','1','0'};
contrasts = {'45_Avg','1_Avg','0_Avg'};

if false
    % Check all data can be read
    warning off;
    data = load_contrasts(ff_contrasts,contrasts,subjects,scaling);
    fprintf('Everything OK\n');
    return
end

if 0 %%%%%%

% For all voxel ranking methods
for r = 1:4
    clear C;
    if r == 1
        C.method = 'stump';
    elseif r == 2
        C.method = 'normal';
    elseif r == 3
        C.method = 'gnb27';
    elseif r == 4
        C.method = 'tstat';
	else
		error('r has wrong value');
    end

    % Rank voxels
    for t = 1:length(tasks)
        rank_voxels(ff_contrasts,root_output,tasks{t},contrasts{t},subjects,labels,fold_subject,scaling,C);
    end
end

end %%%%%%

% For all feature selection methods
for f = 1:8
    clear C;
    if f == 1
        C.method = 'cluster';
        C.quantile = 99.5;
    elseif f == 2
        C.method = 'pca';
        C.components = inf;
    elseif f == 3
        C.method = 'ica';
        C.components = inf;
    elseif f == 4
        C.method = 'cubes';
        C.size = 5;
    elseif f == 5
        C.method = 'discrim';
        C.voxels = 100;
    elseif f == 6
        C.method = 'active';
        C.voxels = 100;
    elseif f == 7
        C.method = 'slight';
        C.voxels = 100;
    elseif f == 8
        C.method = 'rfesvm';
        C.voxels = 100;
        C.remove = 1000;
	else
		error('f has wrong value');
    end

if 0 %%%%%%
    
    % Select features
    for t = 1:length(tasks)
        select_features(ff_contrasts,root_output,tasks{t},contrasts{t},subjects,labels,fold_subject,scaling,C);
    end

    % Extract features
    extract_features(ff_contrasts,root_output,tasks,contrasts,subjects,labels,fold_subject,scaling,C);

end %%%%%%
    
    % For all classification methods
    features = feature_name(C);
    for c = 1:9
        clear C;
        if c == 1
            C.classifier = 'majvote';
        elseif c == 2
            C.classifier = 'majvote1';
        elseif c == 3
            C.classifier = 'gnb';
        elseif c == 4
            C.classifier = 'knn';
            C.neighbors = [1 2 5 10 20];
        elseif c == 5
            C.classifier = 'fld';
            C.ridge = 1e-8;
        elseif c == 6
            C.classifier = 'slogreg';
            C.rho = [1 10 100 1000 10000];
        elseif c == 7
            C.classifier = 'svmlin';
        elseif c == 8
            C.classifier = 'svmrbf';
            C.gamma = [1 10 100 1000 10000];
        elseif c == 9
            C.classifier = 'adaboost';
            C.iterations = [5 10 20 50 100];
        else
            error('c has wrong value');
        end

        % Perform cross-validation
        ff_features = fullfile(root_output,'features_[features]','extract.mat');
        root_reports = fullfile(root_output,'reports');
        classify(ff_features,root_reports,tasks,1:length(tasks),features,C);
    end
end
