% [test_labels test_values C] = slogreg(test_data,train_data,train_labels,rho);
%
% Run logistic regression
% Learns on train set, predicts test set
%   train_data, test_data: #instances by #features data matrices
%   train_labels:          #instances vector (with values 1 or 2)
%   rho:                   double
%
% Author: Jean Honorio
% E-mail: jhonorio@csail.mit.edu
function [test_labels test_values C] = slogreg(test_data,train_data,train_labels,rho);

% Check input
[num_instances num_features] = size(train_data);
if size(test_data,2) ~= num_features
    error('Training and testing set have different number of features');
end
if length(train_labels) ~= num_instances
    error('Number of labels is different from number of instances in training set');
end
if ~exist('rho','var')
    rho = 0;
end

% Learn on training data
X = [train_data ones(num_instances,1)];
y = train_labels(:);
y(y == 2) = -1;
% LogisticLoss maximizes: sum(log(1+exp(-y.*(X*theta))))
% I checked the value of the function, and also the source
% code for the gradient
fun_obj = @(theta) LogisticLoss(theta,X,y);
zz = zeros(num_features+1,1);
lambda = [rho*ones(num_features,1); 0];
options.order = -1;
options.verbose = false;
C.weight = L1GeneralProjection(fun_obj,zz,lambda,options);

% Predict on test data
test_values = [test_data ones(size(test_data,1),1)] * C.weight;
test_labels = 2 - double(test_values > 0);
